@@ -42,28 +42,30 @@ class DCViewPlugin(p.SingletonPlugin):
 
     # IResourceController
     def after_create(self, context, resource):
-        """Generate preview image and html file"""
-        jid = "-".join([resource["id"], resource["name"], "preview"])
-        condense_jid = "-".join([resource["id"], resource["name"], "condense"])
-        exts = config.get("ckan.plugins")
-        if "dc_serve" in exts:
-            # The dc_serve extension is available, which produces a condensed
-            # dataset. We can use that for plotting.
-            rq_kwargs = {"timeout": 60,
-                         "job_id": jid,
-                         "depends_on": condense_jid}
-            queue = "dcor-normal"
-        else:
-            # The dc_serve extension is NOT available. Creating the preview
-            # image might take longer.
-            rq_kwargs = {"timeout": 1800,
-                         "job_id": jid}
-            queue = "dcor-long"
-        toolkit.enqueue_job(create_preview_job,
-                            [resource],
-                            title="Create resource preview image",
-                            queue=queue,
-                            rq_kwargs=rq_kwargs)
+        """Generate preview data"""
+        if resource.get('mimetype') in DC_MIME_TYPES:
+            jid = "-".join([resource["id"], resource["name"], "preview"])
+            condense_jid = "-".join([resource["id"], resource["name"],
+                                     "condense"])
+            exts = config.get("ckan.plugins")
+            if "dc_serve" in exts:
+                # The dc_serve extension is available, which produces a
+                # condensed dataset. We can use that for plotting.
+                rq_kwargs = {"timeout": 60,
+                             "job_id": jid,
+                             "depends_on": condense_jid}
+                queue = "dcor-normal"
+            else:
+                # The dc_serve extension is NOT available. Creating the preview
+                # image might take longer.
+                rq_kwargs = {"timeout": 1800,
+                             "job_id": jid}
+                queue = "dcor-long"
+            toolkit.enqueue_job(create_preview_job,
+                                [resource],
+                                title="Create resource preview image",
+                                queue=queue,
+                                rq_kwargs=rq_kwargs)
 
     # IResourceView
     def info(self):
